package cn.fw.valhalla.domain.enums;

import com.baomidou.mybatisplus.core.enums.IEnum;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import lombok.Getter;

/**
 * @author : kurisu
 * @className : SettingTypeEnum
 * @description : 设置类型
 * @date: 2020-08-11 17:37
 */
public enum SettingTypeEnum implements IEnum<Integer> {
    /**
     * 首次触发时间
     */
    FIRST_TRIGGER_TIME(1, "首次触发时间", 1),
    /**
     * 有效跟进时间
     */
    EFFECTIVE_TIME(2, "有效跟进时间", 2),
    /**
     * 跟进周期
     */
    FOLLOW_CYCLE(3, "跟进周期", 3),
    /**
     * 划走时间[二次分配时间]
     * 即到期前X天做二次分配
     */
    CHANGE_TIME(4, "划走时间", 4),
    /**
     * 失败时间
     */
    FAIL_TIME(5, "失败时间", 5),
    /**
     * 首次触发消息提醒时间
     */
    FIRST_NOTICE_TIME(6, "首次触发消息提醒时间", 6),
    /**
     * 消息间隔
     */
    NOTICE_CYCLE(7, "消息间隔", 7),
    /**
     * 提醒次数
     */
    NOTICE_TIMES(8, "提醒次数", 8),
    /**
     * 首保集团标准最低值（首保only）
     */
    REVISE_RATIO(9, "集团标准最低值", 9),
    /**
     * 待办时效（事故车 only）
     */
    LIMITATION(10, "待办时效", 0),
    /**
     * 客户保持率最低要求
     */
    RETENTION_RATIO(11, "客户保持率最低要求", 10),
    /**
     * 公共客户线索池保留最大时长
     */
    PUBLIC_VALID_DAY(12, "公共客户线索池保留时间", 11),
    /**
     * 公共客户线索最低转换率
     */
    MINIMUM_CONVERSION_RATE(13, "公共客户线索最低转换率", 12),
    MINIMUM_CLUE_COUNT(14, "公共客户线索分配初始数", 13),
    INCREASE_COUNT(15, "公共客户线增量数", 14),
    /**
     * 进站率目标(%),百分数
     */
    PIT_STOP_RATIO(16, "进站率目标", 15),
    /**
     * 保持率计算上限
     */
    RETENTION_MAX_RATIO(17, "保持率计算上限", 16),
    /**
     * 进站率最高要求
     */
    MAX_PIT_STOP_RATIO(18, "进站率最高要求", 17),
    PRIORITY_ROLE(98, "续保优先跟进角色", 1001),
    MODE(99, "续保跟进模式", 1000),
    ;

    /**
     * 值
     */
    private final Integer value;
    /**
     * 名称
     */
    @Getter
    private final String name;

    @Getter
    private final Integer seq;

    SettingTypeEnum(final Integer value, final String name, final Integer seq) {
        this.value = value;
        this.name = name;
        this.seq = seq;
    }

    /**
     * 根据枚举值获取枚举对象
     */
    @JsonCreator
    public static SettingTypeEnum ofValue(final Integer value) {
        for (final SettingTypeEnum typeEnum : SettingTypeEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum;
            }
        }
        return null;
    }

    /**
     * 获取值
     *
     * @return 值
     */
    @JsonValue
    @Override
    public Integer getValue() {
        return value;
    }

    /**
     * 获取描述
     *
     * @return 值
     */
    @JsonCreator
    public static String getNameByVale(final Integer value) {
        for (final SettingTypeEnum typeEnum : SettingTypeEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum.getName();
            }
        }
        return "";
    }
}
