package cn.fw.valhalla.rpc.hermes;

import cn.fw.data.base.domain.common.Message;
import cn.fw.hermes.sdk.v2.para.HermesPair;
import cn.fw.hermes.sdk.v2.para.HermesTriple;
import cn.fw.hermes.sdk.v2.para.MsgV2Condition;
import cn.fw.hermes.sdk.v2.result.MessageV2Result;
import cn.fw.hermes.sdk.v2.service.IMessageV2Service;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Map;

/**
 * 消息推送rpc
 *
 * @author : kurisu
 * @version : 2.0
 * @desc : 消息推送rpc
 * @date : 2023-07-25 11:04
 */
@Slf4j
@Service
@RequiredArgsConstructor
public class HermesRpcService {
    private final IMessageV2Service messageV2Service;

    public void sendTextMsg(String text, Long userId) {
        try {
            MsgV2Condition condition = MsgV2Condition.createTextCondition(text, userId, false);
            Message<MessageV2Result> msg = messageV2Service.sendMsg(condition);
            log.info("给[{}]推送im消息结果:[{}]", userId, msg.getData());
        } catch (Exception e) {
            log.error("给[{}]推送im消息失败", userId, e);
        }
    }

    public void sendImageMsg(String url, Long userId) {
        try {
            MsgV2Condition condition = MsgV2Condition.createImageCondition(HermesTriple.of(url, url, url), userId, false);
            Message<MessageV2Result> msg = messageV2Service.sendMsg(condition);
            log.info("给[{}]推送im消息结果:[{}]", userId, msg.getData());
        } catch (Exception e) {
            log.error("给[{}]推送im消息失败", userId, e);
        }
    }

    public void sendVideoMsg(String url, Long userId) {
        try {
            MsgV2Condition condition = MsgV2Condition.createVideoCondition(HermesTriple.of(url, url, 30), userId, false);
            Message<MessageV2Result> msg = messageV2Service.sendMsg(condition);
            log.info("给[{}]推送im消息结果:[{}]", userId, msg.getData());
        } catch (Exception e) {
            log.error("给[{}]推送im消息失败", userId, e);
        }
    }

    public void sendVoiceMsg(String url, Long userId) {
        try {
            MsgV2Condition condition = MsgV2Condition.createVoiceCondition(HermesPair.of(url, 30), userId, false);
            Message<MessageV2Result> msg = messageV2Service.sendMsg(condition);
            log.info("给[{}]推送im消息结果:[{}]", userId, msg.getData());
        } catch (Exception e) {
            log.error("给[{}]推送im消息失败", userId, e);
        }
    }

    public void sendEmojiMsg(int idx, Long userId) {
        try {
            MsgV2Condition condition = MsgV2Condition.createEmojiCondition(idx, userId, false);
            Message<MessageV2Result> msg = messageV2Service.sendMsg(condition);
            log.info("给[{}]推送im消息结果:[{}]", userId, msg.getData());
        } catch (Exception e) {
            log.error("给[{}]推送im消息失败", userId, e);
        }
    }

    public void sendLocationMsg(String address, Long userId) {
        try {
            MsgV2Condition condition = MsgV2Condition.createLocationCondition(HermesTriple.of(address, BigDecimal.valueOf(35.53211), BigDecimal.valueOf(119.2344)), userId, false);
            Message<MessageV2Result> msg = messageV2Service.sendMsg(condition);
            log.info("给[{}]推送im消息结果:[{}]", userId, msg.getData());
        } catch (Exception e) {
            log.error("给[{}]推送im消息失败", userId, e);
        }
    }

    public void sendCustomMsg(Long targetUserId, String data) {
        try {
            final String msgBizType = "SenderNotice";
            Map<String, Object> ext = new HashMap<>(2);
            ext.put("type", msgBizType);
            ext.put("data", data);
            MsgV2Condition condition = MsgV2Condition.createCustomCondition(ext, targetUserId, false);
            Message<Long> msg = messageV2Service.asyncSendMsg(condition);
            log.info("给[{}]推送im消息结果:[{}]", targetUserId, msg.getData());
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

}
