package cn.fw.valhalla.sdk.param;

import lombok.Data;
import org.hibernate.validator.constraints.ScriptAssert;

import javax.validation.constraints.NotNull;
import java.util.List;

/**
 * 进站率目标
 *
 * @author : kurisu
 * @version : 1.3.0
 * @className : InboundRateTargetReq
 * @description : 进站率目标
 * @date : 2023-06-06 09:12
 */
@Data
@ScriptAssert.List({
        @ScriptAssert(lang = "javascript", script = "_this.checkParams()", message = "人员列表和门店列表不能同时为空"),
})
public class InboundRateTargetReq {
    /**
     * 员工ID列表
     */
    private List<Long> staffUserIds;
    /**
     * 门店列表
     */
    private List<Long> shopIds;
    /**
     * 集团id
     */
    @NotNull(message = "集团id不能为空")
    private Long groupId;

    private boolean checkParams() {
        boolean emptyUser = staffUserIds == null || staffUserIds.isEmpty();
        boolean emptyShop = shopIds == null || shopIds.isEmpty();
        return !emptyUser || !emptyShop;
    }
}
