package cn.fw.valhalla.controller.app

import cn.fw.common.web.annotation.ControllerMethod
import cn.fw.common.web.auth.LoginAuthBean
import cn.fw.common.web.auth.annotation.CurrentUser
import cn.fw.common.web.util.ResultBuilder.success
import cn.fw.data.base.domain.common.Message
import cn.fw.security.auth.client.annotation.Authorization
import cn.fw.security.auth.client.enums.AuthType
import cn.fw.valhalla.domain.dto.AccidentPoolDTO
import cn.fw.valhalla.service.bus.cust.AccidentPoolBizService
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.validation.annotation.Validated
import org.springframework.web.bind.annotation.PostMapping
import org.springframework.web.bind.annotation.RequestBody
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController
import javax.validation.Valid

/**
 * 事故车处理控制器
 *
 * @author : kurisu
 * @version : 1.0
 * @desc : 事故车处理控制器
 * @date : 2024-02-29 17:50
 */
@RestController
@Authorization(AuthType.APP)
@Validated
@RequestMapping("/app/accident")
class AccidentCarController @Autowired constructor(private val accidentPoolBizService: AccidentPoolBizService) {
    @PostMapping("/pool/save")
    @ControllerMethod("新增事故车线索")
    fun save(
        @CurrentUser currentUser: LoginAuthBean,
        @RequestBody accidentPoolDTO: @Valid AccidentPoolDTO?
    ): Message<Long> {
        return success(accidentPoolBizService.add2Pool(currentUser, accidentPoolDTO))
    }
}