package cn.fw.valhalla.controller.task;

import cn.fw.valhalla.common.utils.StringUtils;
import cn.fw.valhalla.common.utils.ThreadPoolUtil;
import cn.fw.valhalla.service.bus.cust.CommonBizService;
import lombok.AccessLevel;
import lombok.Getter;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.CompletableFuture;

/**
 * 档案变动后发送mq
 *
 * @author : kurisu
 * @version : 1.0
 * @className : NoticeCustomerChange
 * @description : 档案变动后发送mq
 * @date : 2023-05-30 14:48
 */
@Component
@Slf4j
@ConditionalOnProperty(prefix = "task", name = "switch", havingValue = "on")
public class NoticeCustomerChange {
    private final StringRedisTemplate redisTemplate;
    private final CommonBizService commonBizService;
    @Value("${spring.cache.custom.global-prefix}:customer:change:prepare")
    @Getter(AccessLevel.PRIVATE)
    private String customerChangeKey;

    @Autowired
    public NoticeCustomerChange(final StringRedisTemplate redisTemplate, final CommonBizService commonBizService) {
        this.redisTemplate = redisTemplate;
        this.commonBizService = commonBizService;
    }

    @Scheduled(initialDelay = 1000 * 15, fixedRate = 1000 * 10)
    public void notice() {
        List<String> failList = new ArrayList<>();
        for (int i = 0; i < 100; i++) {
            String idStr = redisTemplate.opsForSet().pop(getCustomerChangeKey());
            try {
                if (StringUtils.isEmpty(idStr)) {
                    continue;
                }
                final Long id = Long.valueOf(idStr);
                CompletableFuture.runAsync(() -> commonBizService.sendNotice(id), ThreadPoolUtil.getInstance().getExecutor());
            } catch (Exception e) {
                if (StringUtils.isValid(idStr)) {
                    failList.add(idStr);
                }
                log.error("档案变动后发送mq: {}", e.getMessage());
            }
        }

        if (!CollectionUtils.isEmpty(failList)) {
            String[] array = failList.toArray(new String[0]);
            redisTemplate.opsForSet().add(getCustomerChangeKey(), array);
        }
    }
}
