package cn.fw.valhalla.controller.task

import cn.fw.valhalla.common.utils.StringUtils
import cn.fw.valhalla.domain.db.OriginalData
import cn.fw.valhalla.service.bus.ReachLogBizService
import cn.fw.valhalla.service.bus.follow.FollowBizService
import cn.fw.valhalla.service.data.OriginalDataService
import com.baomidou.mybatisplus.core.toolkit.Wrappers
import org.springframework.beans.factory.annotation.Value
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty
import org.springframework.data.redis.core.StringRedisTemplate
import org.springframework.scheduling.annotation.Scheduled
import org.springframework.stereotype.Component

/**
 * 原始数据处理
 *
 * @author : kurisu
 * @version : 1.0
 * @desc : 原始数据处理
 * @date : 2024-03-07 10:45
 */
@Component
@ConditionalOnProperty(prefix = "task", name = ["switch"], havingValue = "on")
class OriginDataDealTask(
    private val originalDataService: OriginalDataService,
    private val followBizService: FollowBizService,
    private val stringRedisTemplate: StringRedisTemplate,
    private val reachLogBizService: ReachLogBizService,
    @Value("\${spring.cache.custom.global-prefix}:reach-log:cache")
    private val reachLogKey: String
) {


    @Scheduled(initialDelay = 1000 * 15, fixedRate = 1000 * 15)
    fun syn2Task() {
        val list = originalDataService.list(
            Wrappers.lambdaQuery<OriginalData>()
                .eq(OriginalData::getSolved, false)
                .last("limit 0,500")
        )
        if (list.isNullOrEmpty()) {
            return
        }
        for (data in list) {
            val solved = followBizService.origin2task(data, data.type)
            data.solved = solved
        }
        originalDataService.updateBatchById(list)
    }

    @Scheduled(cron = "0/30 * * * * *")
    fun saveReachData() {
        val failList: MutableList<String> = mutableListOf()
        val listOps = stringRedisTemplate.boundListOps(reachLogKey)
        listOps.size()?.takeIf { it > 0 }?.let {
            while (true) {
                val dataStr = listOps.leftPop()
                if (dataStr.isNullOrBlank()) {
                    break
                }
                try {
                    reachLogBizService.saveReachLog(dataStr)
                } catch (e: Exception) {
                    if (StringUtils.isValid(dataStr)) {
                        failList.add(dataStr)
                    }
                }
            }
        }
        if (failList.isNotEmpty()) {
            stringRedisTemplate.opsForList().rightPushAll(reachLogKey, failList)
        }
    }
}