package cn.fw.valhalla.controller.task

import cn.fw.valhalla.service.bus.follow.FollowBizService
import org.slf4j.Logger
import org.slf4j.LoggerFactory
import org.springframework.beans.factory.annotation.Value
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty
import org.springframework.data.redis.core.StringRedisTemplate
import org.springframework.scheduling.annotation.Scheduled
import org.springframework.stereotype.Component

/**
 * 二次分配任务
 *
 * @author : kurisu
 * @version : 1.0
 * @desc : 二次分配任务
 * @date : 2024-03-08 11:07
 */
@Component
@ConditionalOnProperty(prefix = "task", name = ["switch"], havingValue = "on")
class SecondFollowTask(
    private val followBizService: FollowBizService,
    private val stringRedisTemplate: StringRedisTemplate,
    @Value("\${spring.cache.custom.global-prefix}:follow:clue:second")
    private val clueSecondKey: String
) {
    val logger: Logger = LoggerFactory.getLogger(javaClass)

    @Scheduled(initialDelay = 1000 * 15, fixedRate = 1000 * 5)
    fun secondFollow() {
        val failedList: MutableList<String> = mutableListOf()
        val boundSetOps = stringRedisTemplate.boundSetOps(clueSecondKey)
        for (i in 0..(2 shl 8)) {
            val tasIdStr = boundSetOps.pop()
            val taskId = tasIdStr?.toLong() ?: break
            try {
                followBizService.doSecondFollow(taskId)
            } catch (e: Exception) {
                logger.error("二次分配失败，taskId: $taskId", e)
                failedList.add(taskId.toString())
            }
        }

        failedList.forEach {
            boundSetOps.add(it)
        }
    }
}