package cn.fw.valhalla.controller.wx;

import cn.fw.common.web.annotation.ControllerMethod;
import cn.fw.common.web.auth.PassportAuthBean;
import cn.fw.common.web.auth.annotation.CurrentUser;
import cn.fw.data.base.domain.common.Message;
import cn.fw.security.auth.client.annotation.Authorization;
import cn.fw.security.auth.client.enums.AuthType;
import cn.fw.valhalla.domain.dto.NewCustomerDTO;
import cn.fw.valhalla.domain.vo.customer.CarArchiveVO;
import cn.fw.valhalla.service.bus.cust.CustomerBizService;
import cn.fw.valhalla.service.bus.cust.CustomerChangeBizService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

import static cn.fw.common.web.util.ResultBuilder.success;

/**
 * @author : kurisu
 * @className : CustomerWxController
 * @description : 档案微信端控制器
 * @date: 2020-08-13 15:00
 */
@Slf4j
@Validated
@RestController
@Authorization(AuthType.WECHAT)
@RequestMapping("/wx/customer")
public class CustomerWxController {
    private final CustomerBizService customerBizService;
    private final CustomerChangeBizService changeBizService;

    @Autowired
    public CustomerWxController(final CustomerBizService customerBizService,
                                final CustomerChangeBizService changeBizService) {
        this.customerBizService = customerBizService;
        this.changeBizService = changeBizService;
    }
    /**
     * 查询所有档案
     *
     * @param user
     * @return
     */
    @GetMapping("/car/list")
    @ControllerMethod("查询所有档案")
    public Message<List<CarArchiveVO>> carList(@CurrentUser PassportAuthBean user) {
        return success(customerBizService.defaultCustomer(user.getUserId()));
    }

    /**
     * 新增变更档案
     *
     * @param user
     * @param dto
     * @return
     */
    @PostMapping("/new/save")
    @ControllerMethod("新增档案信息")
    public Message<Void> saveCustomer(@CurrentUser PassportAuthBean user, @Validated @RequestBody final NewCustomerDTO dto) {
        dto.setMemberId(user.getUserId());
        changeBizService.saveCustomer(dto);
        return success();
    }

}
