package cn.fw.valhalla.service.bus.follow;

import cn.fw.valhalla.domain.db.follow.FollowRecord;
import cn.fw.valhalla.domain.db.follow.FollowRecordLog;
import cn.fw.valhalla.domain.dto.FollowAttachmentDTO;
import cn.fw.valhalla.domain.enums.FollowTypeEnum;
import cn.fw.valhalla.service.data.FollowRecordLogService;
import cn.fw.valhalla.service.data.FollowRecordService;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;

import java.util.Date;
import java.util.List;
import java.util.Objects;

import static cn.fw.common.businessvalidator.Validator.BV;

/**
 * @author : kurisu
 * @className : PCFollowBizService
 * @description : 公共池跟进逻辑处理
 * @date: 2020-08-17 10:48
 */
@Slf4j
@Service
@RequiredArgsConstructor
public class PCFollowBizService {

    private final FollowRecordService followRecordService;
    private final FollowRecordLogService followRecordLogService;



    @Transactional(rollbackFor = Exception.class)
    public void uploadAtt(FollowAttachmentDTO dto, Long userId) {
        FollowRecord record = followRecordService.getById(dto.getRecordId());
        if (Objects.isNull(record)) {
            return;
        }
        BV.isTrue(record.getUserId().equals(userId), () -> "无法跟进非本人的任务");
        FollowRecordLog recordLog = new FollowRecordLog();
        recordLog.setId(dto.getId());
        recordLog.setTaskId(record.getTaskId());
        recordLog.setAttachments(dto.getAttachments());
        recordLog.setAttType(dto.getAttTypeEnum());
        recordLog.setFeedbackType(dto.getFeedbackTypeEnum());
        recordLog.setDescribes(dto.getDescribes());
        recordLog.setRecordId(dto.getRecordId());
        if (Objects.isNull(dto.getId())) {
            recordLog.setUploadTime(new Date());
        }
        followRecordLogService.saveOrUpdate(recordLog);
    }

    public void overdueProcessing() {
        List<FollowRecord> list = followRecordService.list(Wrappers.<FollowRecord>lambdaUpdate()
                .eq(FollowRecord::getOutTime, Boolean.FALSE)
                .eq(FollowRecord::getType, FollowTypeEnum.OT)
                .lt(FollowRecord::getDeadline, new Date())
        );
        if (CollectionUtils.isEmpty(list)) {
            return;
        }
        list.forEach(record -> record.setOutTime(Boolean.TRUE));
        followRecordService.updateBatchById(list);
    }
}
