package cn.fw.valhalla.service.bus.ipt

import cn.fw.common.data.mybatis.pagination.PageData
import cn.fw.common.page.AppPage
import cn.fw.valhalla.domain.db.ipt.CustomerInitClue
import cn.fw.valhalla.domain.db.ipt.CustomerInitClueCallLog
import cn.fw.valhalla.domain.query.InitClueQueryVO
import cn.fw.valhalla.domain.vo.AppPageVO
import cn.fw.valhalla.domain.vo.ipt.CustomerInitClueVO
import cn.fw.valhalla.domain.vo.ipt.InitClueCallLogVO
import cn.fw.valhalla.rpc.member.MemberRpcService
import cn.fw.valhalla.rpc.oop.OopService
import cn.fw.valhalla.service.data.CustomerInitClueCallLogService
import cn.fw.valhalla.service.data.CustomerInitClueService
import com.baomidou.mybatisplus.extension.kotlin.KtQueryWrapper
import org.springframework.stereotype.Service
import java.util.*
import java.util.function.Function

/**
 * 期初档案线索
 *
 * @author : kurisu
 * @version : 2.0
 * @desc : 期初档案线索
 * @date : 2024-03-27 17:09
 */
@Service
class CustomerInitClueBizService(
    private val customerInitClueService: CustomerInitClueService,
    private val customerInitClueCallLogService: CustomerInitClueCallLogService,
    private val oopService: OopService,
    private val memberRpcService: MemberRpcService
) {
    /**
     * 查询池子数据
     */
    fun listPage(query: InitClueQueryVO): AppPage<CustomerInitClueVO> {
        val ipage = PageData<CustomerInitClue>(query)
        val page: AppPageVO<CustomerInitClueVO> = AppPageVO.init(query)
        val ktQuery = KtQueryWrapper(CustomerInitClue::class.java)
            .eq(CustomerInitClue::yn, true)
            .eq(CustomerInitClue::groupId, query.groupId)
            .eq(Objects.nonNull(query.adviserId), CustomerInitClue::adviserId, query.adviserId)
            .and(!query.kw.isNullOrBlank()) {
                it.like(CustomerInitClue::plateNo, query.kw)
                    .or()
                    .like(CustomerInitClue::vin, query.kw)
                    .or()
                    .like(CustomerInitClue::customerName, query.kw)
                    .or()
                    .like(CustomerInitClue::senderName, query.kw)
            }
        customerInitClueService.page(ipage, ktQuery)
        page.total = ipage.total
        page.data = ipage.records?.mapNotNull {
            it.toCustomerInitClueVO { id -> oopService.shop(id)?.shopName ?: "-" }.apply {
                cMobileRegion = memberRpcService.attribution(customerMobile)
                sMobileRegion = memberRpcService.attribution(senderMobile)
            }
        }
        return page
    }

    /**
     * 查询具体线索通话记录
     */
    fun callLog(clueId: Long): List<InitClueCallLogVO> {
        return customerInitClueCallLogService.list(
            KtQueryWrapper(CustomerInitClueCallLog::class.java)
                .eq(CustomerInitClueCallLog::clueId, clueId)
                .orderByAsc(CustomerInitClueCallLog::uploadTime)
        )?.map {
            InitClueCallLogVO(
                id = it.id,
                clueId = it.clueId,
                callId = it.callId,
                talkTime = it.talkTime,
                recording = it.recording,
                uploadTime = it.uploadTime,
            )
        } ?: listOf()
    }
}


fun CustomerInitClue.toCustomerInitClueVO(fn: Function<Long, String>): CustomerInitClueVO {
    val shopName = fn.apply(this.shopId)
    return CustomerInitClueVO(
        id = this.id,
        plateNo = this.plateNo,
        vin = this.vin,
        brandName = this.brandName,
        seriesName = this.seriesName,
        specName = this.specName,
        engineNo = this.engineNo,
        buyDate = this.buyDate,
        customerName = this.customerName,
        customerMobile = this.customerMobile,
        arrivalTime = this.arrivalTime,
        arrivalMileage = this.arrivalMileage,
        senderName = this.senderName,
        senderMobile = this.senderMobile,
        adviserId = this.adviserId,
        adviserName = this.adviserName,
        shopId = this.shopId,
        shopName = shopName,
        groupId = this.groupId,
        createTime = this.createTime,
    )
}


